NetworkDioAdapter class

Dio interceptor that records HTTP calls to NetworkInspector.

Usage:

final adapter = NetworkDioAdapter();
networkInspector.addAdapter(adapter);
dio.interceptors.add(adapter);
Mixed-in types

Constructors

NetworkDioAdapter()

Properties

hashCode int
The hash code for this object.
no setterinherited
networkCore NetworkInspectorCore
latefinalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

injectCore(NetworkInspectorCore networkCore) → void
Injects NetworkInspectorCore into adapter.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onError(DioException err, ErrorInterceptorHandler handler) → void
Called when an exception was occurred during the request.
onRequest(RequestOptions options, RequestInterceptorHandler handler) → void
Called when the request is about to be sent.
onResponse(Response response, ResponseInterceptorHandler handler) → void
Called when the response is about to be resolved.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited