developer_tools_network library
Classes
- DeveloperToolEntry
- Simple model describing a single entry in the developer tools overlay.
- DeveloperToolsDockConfig
- Configuration for the docked log panel.
- DeveloperToolsExtension
- Base class for pluggable developer tools extensions.
- DeveloperToolsLogEntry
- Unified representation of a log entry for display in the dock or overlay.
- DeveloperToolsLogSource
- A source of log entries that can be shown in the dock and overlay.
- DeveloperToolsLogSourceRegistry
- Global registry of log sources for the dock.
-
DeveloperToolsMemoryLog<
T> - Generic in-memory log for developer tools extensions.
- DeveloperToolsNetwork
-
Network HTTP Inspector integration for
developer_tools. - NetworkDioAdapter
- Dio interceptor that records HTTP calls to NetworkInspector.
- NetworkFormDataField
- Definition of form data field.
- NetworkFormDataFile
- Definition of data holder of form data file.
- NetworkHttpCall
- Definition of http calls data holder.
- NetworkHttpError
- Definition of http error data holder.
- NetworkHttpRequest
- Definition of http request data holder.
- NetworkHttpResponse
- Definition of http response data holder.
- NetworkInspector
- NetworkInspectorCore
- NetworkLog
- Definition of log data holder.
- NetworkMemoryStorage
- Storage which uses memory to store calls data. It's a default storage method.
- NetworkParser
- Body parser helper used to parsing body data.
Enums
- DeveloperToolsDockPosition
- Position of the docked log panel.
- DeveloperToolsLogLevel
- Severity/level of a log entry for display purposes.
Mixins
- NetworkAdapter
- Adapter mixin which is used in http client adapters.
Functions
-
networkInspectorStatusOverviewToolEntry(
{String? sectionLabel, NetworkInspector? instance}) → DeveloperToolEntry - A DeveloperToolEntry that opens a dialog showing Network inspector status (e.g. whether the inspector is currently opened) with copy-to-clipboard.
-
openNetworkInspectorToolEntry(
{String? sectionLabel, NetworkInspector? instance}) → DeveloperToolEntry - A DeveloperToolEntry that opens the Network HTTP Inspector fullscreen page.
Typedefs
-
DebugInfoCallback
= Future<
String?> Function(BuildContext context) - Signature for a callback that returns debug information as a string.
-
DeveloperToolAction
= FutureOr<
void> Function(BuildContext context) - Signature for a developer tool action.